@@ -1,7 +1,7 @@
 import os
 import socket
 from inspqcommun.identity.keycloak import KeycloakAPI, get_service_account_token, get_token
-from distutils.util import strtobool
+from str2bool import str2bool
 
 class KeycloakEnvironment():
     
@@ -31,7 +31,7 @@ class KeycloakEnvironment():
         self.defaultAdminAuthRealm = defaultAdminAuthRealm
         self.keycloak_enabled = True
         if 'KEYCLOAK_ENABLED' in os.environ:
-            self.keycloak_enabled = bool(strtobool(os.environ['KEYCLOAK_ENABLED']))
+            self.keycloak_enabled = bool(str2bool(os.environ['KEYCLOAK_ENABLED']))
         if 'KEYCLOAK_BASE_URL' in os.environ:
             self.keycloak_url = "{0}/auth".format(os.environ['KEYCLOAK_BASE_URL'])
         else:
@@ -48,7 +48,7 @@ class KeycloakEnvironment():
         self.keycloak_admin_auth_user = os.environ['KEYCLOAK_ADMIN_AUTH_USER'] if 'KEYCLOAK_ADMIN_AUTH_USER' in os.environ else self.defaultAdminAuthUser
         self.keycloak_admin_auth_password = os.environ['KEYCLOAK_ADMIN_AUTH_PASSWORD'] if 'KEYCLOAK_ADMIN_AUTH_PASSWORD' in os.environ else self.defaultAdminAuthPassword
         self.keycloak_admin_auth_realm = os.environ['KEYCLOAK_ADMIN_AUTH_REALM'] if 'KEYCLOAK_ADMIN_AUTH_REALM' in os.environ else self.defaultAdminAuthRealm
-        self.validate_certs = bool(strtobool(os.environ['VALIDATE_CERTS'])) if 'VALIDATE_CERTS' in os.environ else self.defaultValidateCert
+        self.validate_certs = bool(str2bool(os.environ['VALIDATE_CERTS'])) if 'VALIDATE_CERTS' in os.environ else self.defaultValidateCert
         self.kc = self.init_keycloak_api()
 
     def init_keycloak_api(self):
