@@ -5,7 +5,7 @@ from json.decoder import JSONDecodeError
 import os
 import uuid
 from confluent_kafka import Consumer, KafkaException, KafkaError
-from distutils.util import strtobool
+from str2bool import str2bool
 import json
 
 class ConfigurationConsommateurKafka():
@@ -46,7 +46,7 @@ def obtenirConfigurationsConsommateurDepuisVariablesEnvironnement(logger=None):
             print(log_message)
     consumer_enable_partition_eof = False
     try:
-        consumer_enable_partition_eof = strtobool(os.environ['CONSUMER_ENABLE_PARTITON_EOF']) if 'CONSUMER_ENABLE_PARTITON_EOF' in os.environ else False
+        consumer_enable_partition_eof = str2bool(os.environ['CONSUMER_ENABLE_PARTITON_EOF']) if 'CONSUMER_ENABLE_PARTITON_EOF' in os.environ else False
     except ValueError as e:
         log_message = "CONSUMER_ENABLE_PARTITON_EOF set to False due to invalid value. {}".format(str(e))
         if logger is not None:
@@ -59,7 +59,7 @@ def obtenirConfigurationsConsommateurDepuisVariablesEnvironnement(logger=None):
     consumer_auto_offset_reset = os.environ['CONSUMER_AUTO_OFFSET_RESET'] if 'CONSUMER_AUTO_OFFSET_RESET' in os.environ else 'smallest'
     consumer_enable_auto_commit = True
     try:
-        consumer_enable_auto_commit = strtobool(os.environ['CONSUMER_ENABLE_AUTO_COMMIT']) if 'CONSUMER_ENABLE_AUTO_COMMIT' in os.environ else True
+        consumer_enable_auto_commit = str2bool(os.environ['CONSUMER_ENABLE_AUTO_COMMIT']) if 'CONSUMER_ENABLE_AUTO_COMMIT' in os.environ else True
     except ValueError as e:
         log_message = "CONSUMER_ENABLE_AUTO_COMMIT set to True due to invalid value. {}".format(str(e))
         if logger is not None:
