@@ -79,16 +79,16 @@ def publierMessage(producteur, message, topic, logger=None):
         producteur.produce(topic, value=value, key=key, callback=callback_livraison)
         logentry = {}
         logentry['topic'] = topic
-        logentry['key'] = key.decode()
-        logentry['value'] = value.decode()
+        logentry['key'] = key.decode() if key is not None else ""
+        logentry['value'] = value.decode() if value is not None else ""
         logentry['message_code'] = "MESSAGE_PUBLIE"
-        log_message = "Message {} publié sur le topic {}".format(key.decode(), topic)
+        log_message = "Message {} publié sur le topic {}".format(logentry['key'], topic)
         logger.info(log_message, extra=logentry)
     except BufferError as e:
         logentry = {}
         logentry['topic'] = topic
-        logentry['key'] = key.decode()
-        logentry['value'] = value.decode()
+        logentry['key'] = key.decode() if key is not None else ""
+        logentry['value'] = value.decode() if value is not None else ""
         logentry['message_code'] = "PRODUCTEUR_QUEUE_MESSAGE_PLEINE"
         log_message = "La queue de message est pleine. Erreur {}".format(str(e))
         logger.error(log_message, extra=logentry)
@@ -96,8 +96,8 @@ def publierMessage(producteur, message, topic, logger=None):
     except KafkaError as e:
         logentry = {}
         logentry['topic'] = topic
-        logentry['key'] = key.decode()
-        logentry['value'] = value.decode()
+        logentry['key'] = key.decode() if key is not None else ""
+        logentry['value'] = value.decode() if value is not None else ""
         logentry['message_code'] = "ERREUR_PRODUCTEUR"
         logentry['error_code'] = e.error_code
         logentry['reason'] = e.reason
@@ -107,8 +107,8 @@ def publierMessage(producteur, message, topic, logger=None):
     except KafkaException as e:
         logentry = {}
         logentry['topic'] = topic
-        logentry['key'] = key.decode()
-        logentry['value'] = value.decode()
+        logentry['key'] = key.decode() if key is not None else ""
+        logentry['value'] = value.decode() if value is not None else ""
         logentry['message_code'] = "ERREUR_PRODUCTEUR"
         logentry['error_code'] = e.error_code
         logentry['reason'] = e.reason
